@@ -2,18 +2,18 @@
 #
 # Copyright (c) 2018, Nicola Coretti
 # All rights reserved.
-
 import sys
 import abc
 import enum
 import numbers
 import functools
 import argparse
+from itertools import chain
 from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 0
-PATCH_VERSION = 1
+PATCH_VERSION = 2
 
 LIBRARY_VERSION = f'{MAJOR_VERSION}.{MINOR_VERSION}.{PATCH_VERSION}'
 
@@ -37,7 +37,6 @@ class AbstractCrcRegister(metaclass=abc.ABCMeta):
         """
         Initializes the crc register.
         """
-        pass
 
     @abc.abstractmethod
     def update(self, data):
@@ -48,7 +47,6 @@ class AbstractCrcRegister(metaclass=abc.ABCMeta):
                      like object using the built in bytes() function.
         :return: the current value of the crc register.
         """
-        pass
 
     @abc.abstractmethod
     def digest(self):
@@ -58,7 +56,6 @@ class AbstractCrcRegister(metaclass=abc.ABCMeta):
         :return: the final crc checksum.
         :rtype: int.
         """
-        pass
 
     @abc.abstractmethod
     def reverse(self):
@@ -67,11 +64,10 @@ class AbstractCrcRegister(metaclass=abc.ABCMeta):
 
         :return: the the reversed value of the crc register.
         """
-        pass
 
 
 @dataclass(frozen=True)
-class Configuration(object):
+class Configuration:
     """
     A Configuration provides all settings necessary to determine the concrete
     implementation of a specific crc algorithm/register.
@@ -149,7 +145,6 @@ class CrcRegisterBase(AbstractCrcRegister):
         :param byte: the byte which shall be processed by the crc register.
         :return: the new value of the crc register will have after the byte have been processed.
         """
-        pass
 
     def digest(self):
         """
@@ -192,15 +187,12 @@ class CrcRegister(CrcRegisterBase):
         based register.
     """
 
-    def __init__(self, configuration):
-        super().__init__(configuration)
-
     def _process_byte(self, byte):
         """
         See CrcRegisterBase._process_byte
         """
         self.register ^= int(byte) << (self._config.width - 8)
-        for bit in byte:
+        for _ in byte:
             if self._is_division_possible():
                 self.register = (self.register << 1) ^ self._config.polynomial
             else:
@@ -298,16 +290,16 @@ class Byte(numbers.Number):
 
 
 @functools.lru_cache()
-def create_lookup_table(width, polynom):
+def create_lookup_table(width, polynomial):
     """
     Creates a crc lookup table.
 
     :param int width: of the crc checksum.
-    :parma int polynom: which is used for the crc calculation.
+    :parma int polynomial: which is used for the crc calculation.
     """
-    config = Configuration(width=width, polynomial=polynom)
+    config = Configuration(width=width, polynomial=polynomial)
     crc_register = CrcRegister(config)
-    lookup_table = list()
+    lookup_table = []
     for index in range(0, 256):
         crc_register.init()
         data = bytes((index).to_bytes(1, byteorder='big'))
@@ -316,7 +308,7 @@ def create_lookup_table(width, polynom):
     return lookup_table
 
 
-class CrcCalculator(object):
+class CrcCalculator:
 
     def __init__(self, configuration, table_based=False):
         """
@@ -482,14 +474,14 @@ def argument_parser():
     t = subparsers.add_parser('table', help='Generates lookup tables for various crc algorithm settings')
     t.add_argument('width', metavar='<width>', type=into_int,
                    help='width of the crc algorithm, common width\'s are 8, 16, 32, 64')
-    t.add_argument('polynom', metavar='<polynom>', type=into_int,
-                   help='hex value of the polynom used for calculating the crc table')
+    t.add_argument('polynomial', metavar='<polynomial>', type=into_int,
+                   help='hex value of the polynomial used for calculating the crc table')
     t.set_defaults(func=table)
 
     c = subparsers.add_parser('checksum', help='Calculate checksum(s) for the specified input(s)')
     c.add_argument('inputs', nargs='*', type=argparse.FileType('r'), default=[sys.stdin],
                    help='who will be feed into the crc calculation')
-    c.add_argument('-c', '--category', choices=[t for t in CRC_TYPES], default=Crc8.__name__,
+    c.add_argument('-c', '--category', choices=list(CRC_TYPES), default=Crc8.__name__,
                    help='of crc algorithms which shall be used for calculation')
     c.set_defaults(func=checksum)
 
@@ -497,30 +489,37 @@ def argument_parser():
 
 
 def table(args):
-    if not (args.width and args.polynom):
+    if not (args.width and args.polynomial):
         return False
+    columns = 8
     width = args.width
-    polynom = args.polynom
-    lookup_table = create_lookup_table(width, polynom)
-    fmt_spec = '{{:0<0{}X}}'.format(width // 4)
-    template = "0x{} ".format(fmt_spec)
-    for id, entry in enumerate(lookup_table):
-        if (id != 0) and (id % 8 == 0):
-            print()
-        print(template.format(entry), end='')
-    print()
+    polynomial = args.polynomial
+    lookup_table = create_lookup_table(width, polynomial)
+    template = '0x{{:0<0{digits}X}}'.format(digits=width // 4)
+    rows = (lookup_table[i:i + columns] for i in range(0, len(lookup_table), columns))
+    print(
+        "\n".join(
+            (" ".join(
+                (template.format(value) for value in r)
+            ) for r in rows)
+        )
+    )
     return True
 
 
 def checksum(args):
-    data = bytearray()
-    for input in args.inputs:
-        data.extend(bytes(input.read(), 'utf-8'))
     category = CRC_TYPES[args.category]
+    data = bytearray(
+        chain.from_iterable(
+            bytes(src.read(), 'utf-8') for src in args.inputs
+        )
+    )
     for algorithm in sorted(category, key=str):
-        name = f'{algorithm}'.split('.')[1]
-        calculator = CrcCalculator(algorithm, True)
-        print(f'{name}: 0x{calculator.calculate_checksum(data):X}')
+        print(
+            '{name}: 0x{result:X}'.format(
+                name=f'{algorithm}'.split('.')[1],
+                result=CrcCalculator(algorithm, True).calculate_checksum(data))
+        )
     return True
 
 
